
Contributing to pydicom
=======================

If you're interested in contributing to *pydicom* there are many ways to help
out:

* Adding new features, improving existing ones or submitting bug fixes for
  the source code
* Reporting bugs, suggesting improvements or requesting features on the
  :gh:`issue tracker <pydicom/issues>`.
* Reviewing :gh:`existing pull requests <pydicom/pulls>` on GitHub.
* Improving the documentation, whether by fixing typos, contributing
  new material or adding code examples. No change is too small.
* Answering (or asking!) questions on
  `stackoverflow <https://stackoverflow.com/questions/tagged/pydicom>`_,
  the `Google groups page <https://groups.google.com/forum/#!forum/pydicom>`_,
  or :gh:`GitHub <pydicom/issues>`.
* Submitting useful scripts, tutorials or plugins to the
  :gh:`contrib-pydicom <contrib-pydicom>` project


If it's your first time contributing to *pydicom* then we have tutorials for:

* :doc:`Contributing a source code patch <contributing_code>`
* :doc:`Contributing a documentation change <contributing_docs>`
